@@ -3,12 +3,19 @@ package Sort::Sub::asciibetically;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2019-12-15'; # DATE
 our $DIST = 'Sort-Sub'; # DIST
-our $VERSION = '0.113'; # VERSION
+our $VERSION = '0.114'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
 
+sub meta {
+    return {
+        v => 1,
+        summary => 'Sort ascibetically (string-wise)',
+    };
+}
+
 sub gen_sorter {
     my ($is_reverse, $is_ci) = @_;
 
@@ -25,7 +32,7 @@ sub gen_sorter {
 }
 
 1;
-# ABSTRACT: Sort asciibetically (string-wise)
+# ABSTRACT: Sort ascibetically (string-wise)
 
 __END__
 
@@ -35,11 +42,11 @@ __END__
 
 =head1 NAME
 
-Sort::Sub::asciibetically - Sort asciibetically (string-wise)
+Sort::Sub::asciibetically - Sort ascibetically (string-wise)
 
 =head1 VERSION
 
-This document describes version 0.113 of Sort::Sub::asciibetically (from Perl distribution Sort-Sub), released on 2019-12-15.
+This document describes version 0.114 of Sort::Sub::asciibetically (from Perl distribution Sort-Sub), released on 2019-12-15.
 
 =head1 SYNOPSIS
 
@@ -73,7 +80,7 @@ This is equivalent to Perl's:
 
  sub { $a cmp $b }
 
-=for Pod::Coverage ^(gen_sorter)$
+=for Pod::Coverage ^(gen_sorter|meta)$
 
 =head1 HOMEPAGE
 
