@@ -3,12 +3,18 @@ package Sort::Sub::by_length;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2019-12-15'; # DATE
 our $DIST = 'Sort-Sub'; # DIST
-our $VERSION = '0.113'; # VERSION
+our $VERSION = '0.114'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
 
+sub meta {
+    return {
+        v => 1,
+        summary => 'Sort by length of string',
+    };
+}
 sub gen_sorter {
     my ($is_reverse, $is_ci) = @_;
 
@@ -39,7 +45,7 @@ Sort::Sub::by_length - Sort by length of string
 
 =head1 VERSION
 
-This document describes version 0.113 of Sort::Sub::by_length (from Perl distribution Sort-Sub), released on 2019-12-15.
+This document describes version 0.114 of Sort::Sub::by_length (from Perl distribution Sort-Sub), released on 2019-12-15.
 
 =head1 SYNOPSIS
 
@@ -73,7 +79,7 @@ This is equivalent to Perl's:
 
  sub { length($a) <=> length($b) }
 
-=for Pod::Coverage ^(gen_sorter)$
+=for Pod::Coverage ^(gen_sorter|meta)$
 
 =head1 HOMEPAGE
 
