@@ -3,12 +3,19 @@ package Sort::Sub::numerically;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2019-12-15'; # DATE
 our $DIST = 'Sort-Sub'; # DIST
-our $VERSION = '0.113'; # VERSION
+our $VERSION = '0.114'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
 
+sub meta {
+    return {
+        v => 1,
+        summary => 'Sort numerically',
+    };
+}
+
 sub gen_sorter {
     my ($is_reverse, $is_ci) = @_;
 
@@ -39,7 +46,7 @@ Sort::Sub::numerically - Sort numerically
 
 =head1 VERSION
 
-This document describes version 0.113 of Sort::Sub::numerically (from Perl distribution Sort-Sub), released on 2019-12-15.
+This document describes version 0.114 of Sort::Sub::numerically (from Perl distribution Sort-Sub), released on 2019-12-15.
 
 =head1 SYNOPSIS
 
@@ -73,7 +80,7 @@ This is equivalent to:
 
  sub { $a <=> $b }
 
-=for Pod::Coverage ^(gen_sorter)$
+=for Pod::Coverage ^(gen_sorter|meta)$
 
 =head1 HOMEPAGE
 
